@@ -70,7 +70,8 @@
 #'  #landmarks on the body and operculum
 #' land.gps<-rep('a',56); land.gps[39:48]<-'b'
 #'
-#' MT <- modularity.test(Y.gpa$coords,land.gps,CI=FALSE,iter=99)
+#' MT <- modularity.test(Y.gpa$coords,land.gps,CI=FALSE,iter=49)
+#' ## NOTE: for actual analysis one should increase iterations!
 #' summary(MT) # Test summary
 #' plot(MT) # Histogram of CR sampling distribution 
 #' # Result implies modularity present
@@ -88,6 +89,7 @@ modularity.test<-function(A, partition.gp, iter = 999, CI = FALSE, seed = NULL,
             }
   gps<-as.factor(partition.gp)
   gps.obs <- as.factor(rep(gps,k,each = k, length=p*k))
+  if(any(table(gps.obs)==1)){stop("Must have at least two variables per partition.")}
   if(!is.null(seed) && seed=="random") seed = sample(1:iter, 1)
   ngps<-nlevels(gps)
   if (length(dim(A))==2){
