@@ -88,6 +88,7 @@ fast.solve <- function(x) {
   return(res)
 }
 
+
 # pcoa
 # acquires principal coordinates from distance matrices
 # used in all linear model functions with data input
@@ -463,7 +464,7 @@ anc.BM <- function(phy, Y){
     out[n + 1,]
   }))
   
-  if(length(out) == (n-1)) out <- t(out)
+  if(NROW(out) == 1) out <- t(out)
   dimnames(out) <- list(1:phy$Nnode + length(phy$tip.label), colnames(Y))
   out
 }
